@@ -1,16 +1,9 @@
 #' Frequency Table
 #'
 #' This function computes a frequency table with absolute and percentage frequencies
-#' for one or more than one variable.
-#'
-#' By default, the function displays the absolute and percentage frequencies when
-#' specifying one variable, while the function displays only the absolute frequencies
-#' when more than one variable is specified. The function displays valid percentage
-#' frequencies only in the presence of missing values and excludes variables with
-#' all values missing from the analysis. Note that it is possible to mix numeric
-#' variables, factors, and character variables in the data frame specified in the
-#' argument \code{data}. By default, numeric variables are rounded to three digits
-#' before computing the frequency table.
+#' for one or more than one variable. By default, the function displays the absolute
+#' and percentage frequencies when specifying one variable, while the function displays
+#' only the absolute frequencies when specifying more than one variable.
 #'
 #' @param data     a vector, factor, or data frame.
 #' @param ...      an expression indicating the variable names in \code{data},
@@ -59,6 +52,13 @@
 #' @param check    logical: if \code{TRUE} (default), argument specification is checked.
 #' @param output   logical: if \code{TRUE} (default), output is shown on the console.
 #'
+#' @details
+#' The function displays valid percentage frequencies only in the presence of
+#' missing values and excludes variables with all values missing from the analysis.
+#' Note that it is possible to mix numeric variables, factors, and character variables
+#' in the data frame specified in the argument \code{data}. By default, numeric
+#' variables are rounded to three digits before computing the frequency table.
+#'
 #' @author
 #' Takuya Yanagida \email{takuya.yanagida@@univie.ac.at}
 #'
@@ -77,7 +77,8 @@
 #' \item{\code{type}}{type of analysis}
 #' \item{\code{data}}{data frame used for the current analysis}
 #' \item{\code{args}}{specification of function arguments}
-#' \item{\code{result}}{list with result tables, i.e., \code{freq} for absolute
+#' \item{\code{result}}{data frame with absolute frequencies and percentages or
+#'                      list with result tables, i.e., \code{freq} for absolute
 #'                      frequencies, \code{perc} for percentages, and \code{v.perc}
 #'                      for valid percentages}
 #'
@@ -125,89 +126,81 @@ freq <- function(data, ..., print = c("no", "all", "perc", "v.perc"),
   #
   # Initial Check --------------------------------------------------------------
 
-  # Check if input 'data' is missing
-  if (isTRUE(missing(data))) { stop("Please specify a vector, factor, or data frame for the argument 'data'", call. = FALSE) }
-
-  # Check if input 'data' is NULL
-  if (isTRUE(is.null(data))) { stop("Input specified for the argument 'data' is NULL.", call. = FALSE) }
+  # Check if input 'data' is missing or NULL
+  if (isTRUE(missing(data) || is.null(data))) { stop("Please specify a vector, factor, or data frame for the argument 'data'", call. = FALSE) }
 
   #_____________________________________________________________________________
   #
   # Data -----------------------------------------------------------------------
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Data using the argument '...' ####
+  ## Data Using the Argument '...' ####
 
   if (isTRUE(!missing(...))) {
 
-    # Extract data and convert tibble into data frame or vector
     x <- as.data.frame(data[, .var.names(data = data, ...), drop = FALSE])
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Data without using the argument '...' ####
+  ## Data Without Using the Argument '...' ####
 
   } else {
 
-    # Data frame
     x <- as.data.frame(data)
 
   }
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Convert user-missing values into NA ####
+  ## Missing Data ####
+
+  #...................
+  ### Convert User-Missing Values into NA ####
 
   if (isTRUE(!is.null(as.na))) { x <- .as.na(x, na = as.na) }
 
+  #...................
+  ### Check Missing Values ####
+
+  # All values missing
+  if (isTRUE(all(is.na(x)))) { stop("All values in the vector or data frame specified in the argument 'data' are missing.", call. = FALSE) }
+
+  # Exclude variables with all missing
+  if (isTRUE(ncol(x) > 1L)) {
+
+    vapply(x, function(y) all(is.na(y)), FUN.VALUE = logical(1L)) |> (\(p) if (isTRUE(any(p))) {
+
+        # Exclude variables with all values missing
+        x <<- x[, !p, drop = FALSE]
+
+        if (isTRUE(ncol(x) == 0L)) {
+
+          stop(paste0("No variable left for the analysis after excluding variables with all values missing."), call. = FALSE)
+
+        } else {
+
+          warning(paste0("Variables with all values missing were excluded from the analysis: ", paste(names(p), collapse = ", ")), call. = FALSE)
+
+        }
+
+      })()
+
+  }
+
   #_____________________________________________________________________________
   #
   # Input Check ----------------------------------------------------------------
 
-  # Split message
-  message.split <- FALSE
-
   # Check inputs
-  .check.input(logical = c("freq", "labels", "val.col", "append", "output"),
-               numeric = list(round = 1L),
-               s.character = list(print = c("no", "all", "perc", "v.perc")),
+  .check.input(logical = c("freq", "labels", "val.col", "append", "split", "output"), numeric = list(round = 1L), s.character = list(print = c("no", "all", "perc", "v.perc")),
                args = c("digits", "write2"), envir = environment(), input.check = check)
 
   # Additional checks
   if (isTRUE(check)) {
 
-    # Check input 'data': All values missing
-    if (isTRUE(all(is.na(x)))) { stop("All values in the vector or data frame specified in the argument 'data' are missing.", call. = FALSE) }
-
-    # Check input 'data': Exclude variables with all missing
-    if (isTRUE(length(x) > 1L)) {
-
-      x <- vapply(x, function(y) all(is.na(y)), FUN.VALUE = logical(1L)) |>
-        (\(y) if (isTRUE(any(y))) {
-
-          warning(paste0(ifelse(sum(y) == 1L, "Variable ", "Variables "), "with all values missing ", ifelse(sum(y) == 1L, "was ", "were "), "excluded from the analysis: ", paste(names(x)[y], collapse = ", ")), call. = FALSE)
-
-          # Exclude variables with all values missing
-          return(x[, !y, drop = FALSE])
-
-        } else {
-
-          return(x)
-
-        })()
-
-    }
-
     # No frequencies and percentages
-    if (isTRUE(all(print == "no") && !isTRUE(freq))) { stop("Please specify \"all\", \"perc\", or \"v.perc\" for the argument 'print' when specifying freq = FALSE.", call. = FALSE) }
+    if (isTRUE(!isTRUE(freq) && all(print == "no"))) { stop("Please specify \"all\", \"perc\", or \"v.perc\" for the argument 'print' when specifying freq = FALSE.", call. = FALSE) }
 
-    # Check input 'split'
-    if (isTRUE(!is.logical(split))) { stop("Please specify TRUE or FALSE for the argument 'split'.", call. = FALSE) }
-
-    if (isTRUE(split && ncol(x) == 1L)) {
-
-      split <- FALSE
-      message.split <- TRUE
-
-    }
+    # Argument 'split'
+    if (isTRUE(split && ncol(x) == 1L)) { split <- FALSE }
 
   }
 
@@ -215,18 +208,19 @@ freq <- function(data, ..., print = c("no", "all", "perc", "v.perc"),
   #
   # Data and Arguments ---------------------------------------------------------
 
-  # Global variable
-  na <- NULL
-
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Argument 'print' ####
 
-  # One variable
-  if (isTRUE(length(x) == 1L)) {
+  #...................
+  ### One Variable ####
+
+  if (isTRUE(ncol(x) == 1L)) {
 
     if (isTRUE(all(c("no", "all", "perc", "v.perc") %in% print))) { print <- c("perc", "v.perc") }
 
-  # More than one variable
+  #...................
+  ### More than one variable ####
+
   } else {
 
     if (isTRUE(freq)) {
@@ -252,91 +246,69 @@ freq <- function(data, ..., print = c("no", "all", "perc", "v.perc"),
   if (isTRUE(all(print == "all"))) { print <- c("perc", "v.perc") }
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Factor labels ####
+  ## Factor Labels ####
 
-  # Factors
-  x.factor <- vapply(x, function(y) is.factor(y), FUN.VALUE = logical(1L))
+  vapply(x, function(y) is.factor(y), FUN.VALUE = logical(1L)) |> (\(p) if (isTRUE(any(p)) && !isTRUE(labels)) {
 
-  # If at least one factor and !isTRUE(labels)
-  if (isTRUE(any(x.factor)) && !isTRUE(labels)) {
+      # Check factor levels across factors
+      if (isTRUE(sum(p) > 1L)) { lapply(x[, p, drop = FALSE], levels) |> (\(q) if (isTRUE(any(apply(combn(length(x[, p]), 2L), 2L, function(y) !identical(q[[y[1L]]], q[[y[2L]]]))))) { warning("Variable do not have the same factor levels, i.e., values may not be comparable across variables.", call. = FALSE) })() }
 
-    # More than one factor
-    if (isTRUE(sum(x.factor) > 1L)) {
-
-      # Unique factor levels for each variable
-      factor.unique <- lapply(x[, x.factor, drop = FALSE], levels)
-
-      if (isTRUE(any(apply(combn(length(x[, x.factor]), 2L), 2L, function(y) !identical(factor.unique[[y[1L]]], factor.unique[[y[2L]]]))))) {
-
-        warning("Variable do not have the same factor levels, i.e., values may not be comparable across variables.", call. = FALSE)
-
-      }
-
-    }
-
-    # Remove labels
-    x <- data.frame(lapply(x, function(y) if (isTRUE(is.factor(y))) as.numeric(y) else y))
-
-  }
+      # Remove labels
+      x <<- data.frame(lapply(x, function(y) if (isTRUE(is.factor(y))) as.numeric(y) else y))
 
+    })()
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Round numeric variables ####
-
-  # Numeric with more than 'round' digits
-  x.numeric <- names(which(vapply(x[, vapply(x, function(y) is.numeric(y) & !is.integer(y), FUN.VALUE = logical(1L)), drop = FALSE],
-                     function(y) any(na.omit(nchar(gsub("(.*)(\\.)|([0]*$)","", y)) > round)), FUN.VALUE = logical(1L))))
-
-  # If at least one numeric variable
-  if (isTRUE(length(x.numeric) > 0L)) { x[, x.numeric] <- lapply(x[, x.numeric, drop = FALSE], base::round, digits = round) }
-
-  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Exclude variables ####
+  ## Exclude Variables ####
 
   if (isTRUE(!isFALSE(exclude))) {
 
-    if (isTRUE(length(x) > 1L && !split)) {
+    if (isTRUE(ncol(x) > 1L && !split)) {
 
       # Default setting exclude variables with more than 15 unique values
       if (isTRUE(exclude)) { exclude <- 15L }
 
-      x.exclude <- which(vapply(x, function(y) length(unique(na.omit(y))), FUN.VALUE = 1L) > exclude)
+      which(vapply(x, function(y) length(unique(na.omit(y))), FUN.VALUE = 1L) > exclude) |> (\(p) if (isTRUE(length(p) > 0L)) {
 
-      if (isTRUE(length(x.exclude) > 0L)) {
+          x <<- x[, -p, drop = FALSE]
 
-        x <- x[, -x.exclude, drop = FALSE]
+          if (isTRUE(ncol(x) == 0L)) {
 
-        if (isTRUE(length(x) == 0L)) {
+            stop(paste0("No variable left for the analysis after excluding variables with all values missing."), call. = FALSE)
 
-          stop(paste0("After excluding variables with more than ", exclude, " unique values, no variables are left for the analysis."), call. = FALSE)
+          } else {
 
-        } else {
-
-          # Rounded numeric variables
-          if (isTRUE(length(setdiff(x.numeric, names(x.exclude))) > 0L)) {
-
-            warning(paste0("Numeric variables with more than ", round, " digits were rounded: ", paste(setdiff(x.numeric, names(x.exclude)), collapse = ", ")), call. = FALSE)
+            warning(paste0("Variables with more than ", exclude, " unique values were excluded: ", paste(names(p), collapse = ", ")), call. = FALSE)
 
           }
 
-          warning(paste0("Variables with more than ", exclude, " unique values were excluded: ", paste(names(x.exclude), collapse = ", ")), call. = FALSE)
-
-        }
-
-      }
+        })()
 
     }
 
   }
 
+
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Round Numeric Variables ####
+
+  # Numeric variable with more than 'round' digits
+  names(which(vapply(x[, vapply(x, function(y) is.numeric(y) & !is.integer(y), FUN.VALUE = logical(1L)), drop = FALSE], function(y) any(na.omit(nchar(gsub("(.*)(\\.)|([0]*$)","", y)) > round)), FUN.VALUE = logical(1L)))) |> (\(p) if (isTRUE(length(p) > 0L)) {
+
+      x[, p] <<- lapply(x[, p, drop = FALSE], base::round, digits = round)
+
+      warning(paste0("Numeric variables with more than ", round, " digits were rounded: ", paste(p, collapse = ", ")), call. = FALSE)
+
+    })()
+
   #_____________________________________________________________________________
   #
   # Main Function --------------------------------------------------------------
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## One variable ####
+  ## One Variable ####
 
-  if (isTRUE(length(x) == 1L)) {
+  if (isTRUE(ncol(x) == 1L)) {
 
     # Absolute frequencies
     x.abs <- table(x, useNA = "always")
@@ -348,69 +320,65 @@ freq <- function(data, ..., print = c("no", "all", "perc", "v.perc"),
     x.v.perc <- prop.table(table(x, useNA = "no")) * 100L
 
     #...................
-    ### Values in columns ####
+    ### Values in Columns ####
+
     if (!isTRUE(val.col)) {
 
-      freqtab <- data.frame(Value = c(na.omit(suppressWarnings(iconv(na.omit(names(x.abs)), from = "ISO-8859-1", to = "UTF-8"))), NA),
-                            Freq = as.numeric(x.abs),
-                            Perc = as.numeric(x.perc),
-                            V.Perc = c(as.numeric(x.v.perc), NA))
+      result <- data.frame(Value = c(na.omit(suppressWarnings(iconv(na.omit(names(x.abs)), from = "ISO-8859-1", to = "UTF-8"))), NA),
+                           Freq = as.numeric(x.abs),
+                           Perc = as.numeric(x.perc),
+                           V.Perc = c(as.numeric(x.v.perc), NA))
 
       # Convert 'Value' in numeric
-      if(all(grepl("(^(-|\\+)?((\\.?\\d+)|(\\d+\\.\\d+)|(\\d+\\.?))$)|(^(-|\\+)?((\\.?\\d+)|(\\d+\\.\\d+)|(\\d+\\.?))e(-|\\+)?(\\d+)$)", x = na.omit(freqtab$Value)))) {
+      if(all(grepl("(^(-|\\+)?((\\.?\\d+)|(\\d+\\.\\d+)|(\\d+\\.?))$)|(^(-|\\+)?((\\.?\\d+)|(\\d+\\.\\d+)|(\\d+\\.?))e(-|\\+)?(\\d+)$)", x = na.omit(result$Value)))) {
 
         # Do not convert "000", "001", "010" etc. into numeric
-        if (isTRUE(all(substr(na.omit(freqtab$Value), 1L, 1L) != "0"))) { freqtab$Value <- as.numeric(freqtab$Value) }
+        if (isTRUE(all(substr(na.omit(result$Value), 1L, 1L) != "0"))) { result$Value <- as.numeric(result$Value) }
 
       }
 
     #...................
-    ### Values in rows ####
+    ### Values in Rows ####
+
     } else {
 
-      freqtab <- data.frame(matrix(c(x.abs, x.perc, x.v.perc, NA), nrow = 3L, dimnames = list(c ("Freq", "Perc", "V.Perc"), names(x.abs)), byrow = TRUE), check.names = FALSE)
+      result <- data.frame(matrix(c(x.abs, x.perc, x.v.perc, NA), nrow = 3L, dimnames = list(c ("Freq", "Perc", "V.Perc"), names(x.abs)), byrow = TRUE), check.names = FALSE)
 
     }
 
-  }
-
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## More than one variable ####
+  ## More than One Variable ####
 
-  if (isTRUE(length(x) > 1L)) {
+  } else {
 
     #...................
     ### split = FALSE ####
+
     if (!isTRUE(split)) {
 
       # Unique levels
       x.levels <- NULL
 
       # Numeric variables
-      if (isTRUE(any(vapply(x, is.numeric, FUN.VALUE = logical(1L))))) {
-
-        x.levels <- c(x.levels, na.omit(sort(unique(unlist(x[, vapply(x, is.numeric, FUN.VALUE = logical(1L))])))))
-
-      }
+      if (isTRUE(any(vapply(x, is.numeric, FUN.VALUE = logical(1L))))) { x.levels <- c(x.levels, na.omit(sort(unique(unlist(x[, vapply(x, is.numeric, FUN.VALUE = logical(1L))]))))) }
 
       # Factors
       if (isTRUE(any(vapply(x, is.factor, FUN.VALUE = logical(1L))))) {
 
-        f.levels <- sort(unique(unname(unlist(sapply(x[, vapply(x, is.factor, FUN.VALUE = logical(1L))], function(y) (as.character(y)))))))
+        sort(unique(unname(unlist(sapply(x[, vapply(x, is.factor, FUN.VALUE = logical(1L))], function(y) (as.character(y))))))) |>
+          # Factor levels are numbers
+          (\(p) if (isTRUE(all(unlist(strsplit(p, "")) %in% 0L:9L))) {
 
-        # Factor levels are numbers
-        if (isTRUE(all(unlist(strsplit(f.levels, "")) %in% 0L:9L))) {
+             x.levels <<- sort(c(x.levels, as.numeric(p)))
 
-          x.levels <- sort(c(x.levels, as.numeric(f.levels)))
+           # Factor levels are character
+           } else {
 
-        # Factor levels are character
-        } else {
+             x.levels <<- c(x.levels, p)
 
-          x.levels <- c(x.levels, f.levels)
+           })()
 
-        }
-
-      }
+       }
 
       # Character
       if (isTRUE(any(vapply(x, is.character, FUN.VALUE = logical(1L))))) { x.levels <- c(x.levels, na.omit(sort(unique(unlist(x[, vapply(x, is.character, FUN.VALUE = logical(1L))]))))) }
@@ -418,48 +386,39 @@ freq <- function(data, ..., print = c("no", "all", "perc", "v.perc"),
       # Logical
       if (isTRUE(any(vapply(x, is.logical, FUN.VALUE = logical(1L))))) { x.levels <- c(x.levels, c(TRUE, FALSE)) }
 
-      x.levels <- unique(x.levels)
-
       # Absolute frequencies
-      x.abs <- vapply(x, function(y) table(factor(y, levels = x.levels), useNA = "always"), FUN.VALUE = integer(length(x.levels) + 1L))
+      unique(x.levels) |> (\(p) {
 
-      # Percentages
-      x.perc <- apply(x.abs, 2, function(y) ifelse(y != 0L, prop.table(y) * 100L, 0L))
+         x.abs <<- vapply(x, function(y) table(factor(y, levels = p), useNA = "always"), FUN.VALUE = integer(length(p) + 1L))
 
-      # Valid Percentages
-      x.v.perc <- vapply(x, function(y) table(factor(y, levels = x.levels), useNA = "no"), FUN.VALUE = integer(length(x.levels)))
+         # Percentages
+         x.perc <<- vapply(x, function(y) prop.table(table(factor(y, levels = p), useNA = "always")) * 100L, FUN.VALUE = numeric(length(p) + 1L))
 
-      # More than one value
-      if (isTRUE(is.matrix(x.v.perc))) {
+         # Valid Percentages
+         x.v.perc <<- vapply(x, function(y) prop.table(table(factor(y, levels = p), useNA = "no")) * 100L, FUN.VALUE = numeric(length(p))) |>
+           # More than one value or only one value
+           (\(q) if (isTRUE(is.matrix(q))) { apply(q, 2L, function(y) prop.table(y) * 100L) } else { matrix(prop.table(q) * 100L, nrow = 1L, dimnames = list(na.omit(row.names(x.abs)), names(q))) })()
 
-        x.v.perc <- apply(x.v.perc, 2L, function(z) prop.table(z) * 100L)
-
-      # One value
-      } else {
-
-        x.v.perc <- matrix(prop.table(x.v.perc) * 100L, nrow = 1, dimnames = list(na.omit(row.names(x.abs)), names(x.v.perc)))
-
-      }
+         })()
 
       # Values in rows
       if (!isTRUE(val.col)) {
 
         # Absolute frequencies table
-        abs.freqtab <- data.frame(Value = rownames(x.abs), x.abs, row.names = NULL)
+        abs.result <- data.frame(Value = rownames(x.abs), x.abs, row.names = NULL)
 
         # Percentages table
-        perc.freqtab <- data.frame(Value = rownames(x.perc), x.perc, row.names = NULL)
+        perc.result <- data.frame(Value = rownames(x.perc), x.perc, row.names = NULL)
 
         # Valid Percentages table
-        v.perc.freqtab <- data.frame(Value = rownames(x.v.perc), x.v.perc, row.names = NULL)
+        v.perc.result <- data.frame(Value = rownames(x.v.perc), x.v.perc, row.names = NULL)
 
         # Convert 'Value' in numeric
-        if(all(grepl("(^(-|\\+)?((\\.?\\d+)|(\\d+\\.\\d+)|(\\d+\\.?))$)|(^(-|\\+)?((\\.?\\d+)|(\\d+\\.\\d+)|(\\d+\\.?))e(-|\\+)?(\\d+)$)",
-                     x = na.omit(abs.freqtab$Value)))) {
+        if(all(grepl("(^(-|\\+)?((\\.?\\d+)|(\\d+\\.\\d+)|(\\d+\\.?))$)|(^(-|\\+)?((\\.?\\d+)|(\\d+\\.\\d+)|(\\d+\\.?))e(-|\\+)?(\\d+)$)", x = na.omit(abs.result$Value)))) {
 
-          abs.freqtab$Value <- as.numeric(abs.freqtab$Value)
-          perc.freqtab$Value <- as.numeric(perc.freqtab$Value)
-          v.perc.freqtab$Value <- as.numeric(v.perc.freqtab$Value)
+          abs.result$Value <- as.numeric(abs.result$Value)
+          perc.result$Value <- as.numeric(perc.result$Value)
+          v.perc.result$Value <- as.numeric(v.perc.result$Value)
 
         }
 
@@ -467,23 +426,24 @@ freq <- function(data, ..., print = c("no", "all", "perc", "v.perc"),
       } else {
 
         # Absolute frequencies table
-        abs.freqtab <- data.frame(Var = colnames(x.abs), matrix(t(x.abs), nrow = ncol(x.abs), dimnames = list(NULL, rownames(x.abs))), check.names = FALSE)
+        abs.result <- data.frame(Var = colnames(x.abs), matrix(t(x.abs), nrow = ncol(x.abs), dimnames = list(NULL, rownames(x.abs))), check.names = FALSE)
 
         # Percentages table
-        perc.freqtab <- data.frame(Var = colnames(x.perc), matrix(t(x.perc), nrow = ncol(x.perc), dimnames = list(NULL, rownames(x.perc))), check.names = FALSE)
+        perc.result <- data.frame(Var = colnames(x.perc), matrix(t(x.perc), nrow = ncol(x.perc), dimnames = list(NULL, rownames(x.perc))), check.names = FALSE)
 
         # Valid Percentages table
-        v.perc.freqtab <- data.frame(Var = colnames(x.v.perc), matrix(t(x.v.perc), nrow = ncol(x.v.perc), dimnames = list(NULL, rownames(x.v.perc))), check.names = FALSE)
+        v.perc.result <- data.frame(Var = colnames(x.v.perc), matrix(t(x.v.perc), nrow = ncol(x.v.perc), dimnames = list(NULL, rownames(x.v.perc))), check.names = FALSE)
 
       }
 
-      freqtab <- list(freq = abs.freqtab, perc = perc.freqtab, v.perc = v.perc.freqtab)
+      result <- list(freq = abs.result, perc = perc.result, v.perc = v.perc.result)
 
     #...................
     ### split = TRUE ####
+
     } else {
 
-      freqtab <- lapply(x, function(y) misty::freq(y, labels = labels, val.col = val.col, round = round, as.na = as.na, check = FALSE, output = FALSE)$result)
+      result <- lapply(x, function(y) misty::freq(y, labels = labels, val.col = val.col, round = round, as.na = as.na, check = FALSE, output = FALSE)$result)
     }
 
   }
@@ -496,7 +456,7 @@ freq <- function(data, ..., print = c("no", "all", "perc", "v.perc"),
                  type = "freq",
                  data = x,
                  args = list(print = print, freq = freq, split = split, labels = labels, val.col = val.col, round = round, digits = digits, as.na = as.na, write = write, append = append, check = check, output = output),
-                 result = freqtab)
+                 result = result)
 
   class(object) <- "misty.object"
 
@@ -510,11 +470,6 @@ freq <- function(data, ..., print = c("no", "all", "perc", "v.perc"),
   #
   # Output ---------------------------------------------------------------------
 
-  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Message ####
-
-  if (isTRUE(message.split)) { message("Argument 'split' set to FALSE because only one variable was specified in 'data'.") }
-
   if (isTRUE(output)) { print(object, check = FALSE) }
 
   return(invisible(object))
