@@ -2,82 +2,9 @@
 #'
 #' This function computes confidence intervals for the indirect effect based on
 #' the asymptotic normal method, distribution of the product method and the Monte
-#' Carlo method. By default, the function uses the distribution of the product
-#' method for computing the two-sided 95\% asymmetric confidence intervals for
-#' the indirect effect product of coefficient estimator \eqn{\hat{a}\hat{b}}.
-#'
-#' In statistical mediation analysis (MacKinnon & Tofighi, 2013), the indirect
-#' effect refers to the effect of the independent variable \eqn{X} on the outcome
-#' variable \eqn{Y} transmitted by the mediator variable \eqn{M}. The magnitude
-#' of the indirect effect \eqn{ab} is quantified by the product of the the
-#' coefficient \eqn{a} (i.e., effect of \eqn{X} on \eqn{M}) and the coefficient
-#' \eqn{b} (i.e., effect of \eqn{M} on \eqn{Y} adjusted for \eqn{X}). In practice,
-#' researchers are often interested in confidence limit estimation for the indirect
-#' effect. This function offers three different methods for computing the confidence
-#' interval for the product of coefficient estimator \eqn{\hat{a}\hat{b}}:
-#'
-#' \strong{(1) Asymptotic normal method}
-#'
-#' In the asymptotic normal method, the standard error for the product of the
-#' coefficient estimator \eqn{\hat{a}\hat{b}} is computed which is used to create
-#' a symmetrical confidence interval based on the z-value of the standard normal
-#' (\eqn{z}) distribution assuming that the indirect effect is normally distributed.
-#' Note that the function provides three formulas for computing the standard error
-#' by specifying the argument \code{se}:
-#'
-#' \describe{
-#'   \item{\code{"sobel"}}{Approximate standard error by Sobel (1982) using the
-#'   multivariate delta method based on a first order Taylor series approximation:
-#'   \deqn{\sqrt(a^2 \sigma^2_a + b^2 \sigma^2_b)}}
-#'
-#'   \item{\code{"aroian"}}{Exact standard error by Aroian (1947) based on a first
-#'   and second order Taylor series approximation:
-#'   \deqn{\sqrt(a^2 \sigma^2_a + b^2 \sigma^2_b + \sigma^2_a \sigma^2_b)}}
-#'
-#'   \item{\code{"goodman"}}{Unbiased standard error by Goodman (1960):
-#'   \deqn{\sqrt(a^2 \sigma^2_a + b^2 \sigma^2_b - \sigma^2_a \sigma^2_b)}
-#'   Note that the unbiased standard error is often negative and is hence
-#'   undefined for zero or small effects or small sample sizes.}
-#' }
-#'
-#' The asymptotic normal method is known to have low statistical power because
-#' the distribution of the product \eqn{\hat{a}\hat{b}} is not normally distributed.
-#' (Kisbu-Sakarya, MacKinnon, & Miocevic, 2014). In the null case, where both
-#' random variables have mean equal to zero, the distribution is symmetric with
-#' kurtosis of six. When the product of the means of the two random variables is
-#' nonzero, the distribution is skewed (up to a maximum value of \eqn{\pm} 1.5)
-#' and has a excess kurtosis (up to a maximum value of 6). However, the product
-#' approaches a normal distribution as one or both of the ratios of the means to
-#' standard errors of each random variable get large in absolute value (MacKinnon,
-#' Lockwood & Williams, 2004).
-#'
-#' \strong{(2) Distribution of the product method}
-#'
-#' The distribution of the product method (MacKinnon et al., 2002) relies on an
-#' analytical approximation of the distribution of the product of two normally
-#' distributed variables. The method uses the standardized \eqn{a} and \eqn{b}
-#' coefficients to compute \eqn{ab} and then uses the critical values for the
-#' distribution of the product (Meeker, Cornwell, & Aroian, 1981) to create
-#' asymmetric confidence intervals. The distribution of the product approaches
-#' the gamma distribution (Aroian, 1947). The analytical solution for the
-#' distribution of the product is provided by the Bessel function used to the
-#' solution of differential equations and is approximately proportional to the
-#' Bessel function of the second kind with a purely imaginary argument (Craig,
-#' 1936).
-#'
-#' \strong{(3) Monte Carlo method}
-#'
-#' The Monte Carlo (MC) method (MacKinnon et al., 2004) relies on the assumption
-#' that the parameters \eqn{a} and \eqn{b} have a joint normal sampling
-#' distribution. Based on the parametric assumption, a sampling distribution of
-#' the product \eqn{a}\eqn{b} using random samples with population values equal
-#' to the sample estimates \eqn{\hat{a}}, \eqn{\hat{b}}, \eqn{\hat{\sigma}_a},
-#' and \eqn{\hat{\sigma}_b} is generated. Percentiles of the sampling distribution
-#' are identified to serve as limits for a \eqn{100(1 - \alpha)}\% asymmetric
-#' confidence interval about the sample \eqn{\hat{a}\hat{b}} (Preacher & Selig,
-#' 2012). Note that parametric assumptions are invoked for \eqn{\hat{a}} and
-#' \eqn{\hat{b}}, but no parametric assumptions are made about the distribution
-#' of \eqn{\hat{a}\hat{b}}.
+#' Carlo method. By default, the function uses the Monte Carlo method for computing
+#' the two-sided 95\% confidence intervals for the indirect effect product of
+#' coefficient estimator \eqn{\hat{a}\hat{b}}.
 #'
 #' @param a           a numeric value indicating the coefficient \eqn{a}, i.e.,
 #'                    effect of \eqn{X} on \eqn{M}.
@@ -123,6 +50,76 @@
 #' @param output      logical: if \code{TRUE} (default), output is shown on the
 #'                    console.
 #'
+#' @details
+#' \describe{
+#' In statistical mediation analysis (MacKinnon & Tofighi, 2013), the indirect
+#' effect refers to the effect of the independent variable \eqn{X} on the outcome
+#' variable \eqn{Y} transmitted by the mediator variable \eqn{M}. The magnitude
+#' of the indirect effect \eqn{ab} is quantified by the product of the the
+#' coefficient \eqn{a} (i.e., effect of \eqn{X} on \eqn{M}) and the coefficient
+#' \eqn{b} (i.e., effect of \eqn{M} on \eqn{Y} adjusted for \eqn{X}). In practice,
+#' researchers are often interested in confidence limit estimation for the indirect
+#' effect. This function offers three different methods for computing the confidence
+#' interval for the product of coefficient estimator \eqn{\hat{a}\hat{b}}:
+#'
+#' \item{\strong{Asymptotic Normal Method}}{In the asymptotic normal method, the
+#' standard error for the product of the coefficient estimator \eqn{\hat{a}\hat{b}}
+#' is computed which is used to create a symmetrical confidence interval based on
+#' the z-value of the standard normal (\eqn{z}) distribution assuming that the
+#' indirect effect is normally distributed. Note that the function provides three
+#' formulas for computing the standard error by specifying the argument \code{se}:
+#'
+#' \describe{
+#'   \item{\code{"sobel"}}{Approximate standard error by Sobel (1982) using the
+#'   multivariate delta method based on a first order Taylor series approximation:
+#'   \deqn{\sqrt(a^2 \sigma^2_a + b^2 \sigma^2_b)}}
+#'
+#'   \item{\code{"aroian"}}{Exact standard error by Aroian (1947) based on a first
+#'   and second order Taylor series approximation:
+#'   \deqn{\sqrt(a^2 \sigma^2_a + b^2 \sigma^2_b + \sigma^2_a \sigma^2_b)}}
+#'
+#'   \item{\code{"goodman"}}{Unbiased standard error by Goodman (1960):
+#'   \deqn{\sqrt(a^2 \sigma^2_a + b^2 \sigma^2_b - \sigma^2_a \sigma^2_b)}
+#'   Note that the unbiased standard error is often negative and is hence
+#'   undefined for zero or small effects or small sample sizes.}
+#' }
+#'
+#' The asymptotic normal method is known to have low statistical power because
+#' the distribution of the product \eqn{\hat{a}\hat{b}} is not normally distributed.
+#' (Kisbu-Sakarya, MacKinnon, & Miocevic, 2014). In the null case, where both
+#' random variables have mean equal to zero, the distribution is symmetric with
+#' kurtosis of six. When the product of the means of the two random variables is
+#' nonzero, the distribution is skewed (up to a maximum value of \eqn{\pm} 1.5)
+#' and has a excess kurtosis (up to a maximum value of 6). However, the product
+#' approaches a normal distribution as one or both of the ratios of the means to
+#' standard errors of each random variable get large in absolute value (MacKinnon,
+#' Lockwood & Williams, 2004).}
+#'
+#' \item{\strong{Distribution of the product method}}{The distribution of the
+#' product method (MacKinnon et al., 2002) relies on an analytical approximation
+#' of the distribution of the product of two normally distributed variables.
+#' The method uses the standardized \eqn{a} and \eqn{b} coefficients to compute
+#' \eqn{ab} and then uses the critical values for the distribution of the product
+#' (Meeker, Cornwell, & Aroian, 1981) to create asymmetric confidence intervals.
+#' The distribution of the product approaches the gamma distribution (Aroian, 1947).
+#' The analytical solution for the distribution of the product is provided by the
+#' Bessel function used to the solution of differential equations and is approximately
+#' proportional to the Bessel function of the second kind with a purely imaginary
+#' argument (Craig, 1936).}
+#'
+#' \item{\strong{ Monte Carlo Method}}{The Monte Carlo (MC) method (MacKinnon et
+#' al., 2004) relies on the assumption that the parameters \eqn{a} and \eqn{b}
+#' have a joint normal sampling distribution. Based on the parametric assumption,
+#' a sampling distribution of the product \eqn{a}\eqn{b} using random samples
+#' with population values equal to the sample estimates \eqn{\hat{a}}, \eqn{\hat{b}},
+#' \eqn{\hat{\sigma}_a}, and \eqn{\hat{\sigma}_b} is generated. Percentiles of
+#' the sampling distribution are identified to serve as limits for a
+#' \eqn{100(1 - \alpha)}\% asymmetric confidence interval about the sample
+#' \eqn{\hat{a}\hat{b}} (Preacher & Selig, 2012). Note that parametric assumptions
+#' are invoked for \eqn{\hat{a}} and \eqn{\hat{b}}, but no parametric assumptions
+#' are made about the distribution of \eqn{\hat{a}\hat{b}}.}
+#' }
+#'
 #' @author
 #' Takuya Yanagida \email{takuya.yanagida@@univie.ac.at}
 #'
@@ -188,11 +185,11 @@
 #' @export
 #'
 #' @examples
-#' # Example 1: Distribution of the Product Method
+#' # Example 1: Monte Carlo Method
 #' indirect(a = 0.35, b = 0.27, se.a = 0.12, se.b = 0.18)
 #'
-#' # Example 2: Monte Carlo Method
-#' indirect(a = 0.35, b = 0.27, se.a = 0.12, se.b = 0.18, print = "mc")
+#' # Example 2: Distribution of the Product Method
+#' indirect(a = 0.35, b = 0.27, se.a = 0.12, se.b = 0.18, print = "dop")
 #'
 #' # Example 3: Asymptotic Normal Method
 #' indirect(a = 0.35, b = 0.27, se.a = 0.12, se.b = 0.18, print = "asymp")
@@ -211,20 +208,15 @@ indirect <- function(a, b, se.a, se.b, print = c("all", "asymp", "dop", "mc"),
 
   # Check inputs
   .check.input(logical = c("append", "output"),
-               numeric = list(nrep = 1L, seed = 1L),
+               numeric = list(a = 1L, b = 1L, nrep = 1L, seed = 1L),
                s.character = list(print = c("all", "asymp", "dop", "mc"), se = c("sobel", "aroian", "goodman")),
                args = c("alternative", "conf.level", "digits", "write1"), envir = environment(), input.check = check)
 
   # Additional checks
   if (isTRUE(check)) {
 
-    # Check input 'a', 'b', 'se.a', and 'se.b'
-    if (isTRUE(mode(a) != "numeric")) { stop("Please specify a numeric value for the argument 'a'.", call. = FALSE) }
-
-    if (isTRUE(mode(b) != "numeric")) { stop("Please specify a numeric value for the argument 'b'.", call. = FALSE) }
-
+    # Check input 'se.a', and 'se.b'
     if (isTRUE(mode(se.a) != "numeric" || se.a <= 0L)) { stop("Please specify a positive numeric value for the argument 'se.a'.", call. = FALSE) }
-
     if (isTRUE(mode(se.b) != "numeric" || se.a <= 0L)) { stop("Please specify a positive numeric value for the argument 'se.b'.", call. = FALSE) }
 
   }
@@ -236,7 +228,7 @@ indirect <- function(a, b, se.a, se.b, print = c("all", "asymp", "dop", "mc"),
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Print Confidence intervals ####
 
-  if(all(c("all", "asymp", "dop", "mc") %in% print)) { print <- "dop" }
+  if(all(c("all", "asymp", "dop", "mc") %in% print)) { print <- "mc" }
 
   if (isTRUE(all(print == "all"))) { print <- c("asymp", "dop", "mc") }
 
@@ -254,229 +246,147 @@ indirect <- function(a, b, se.a, se.b, print = c("all", "asymp", "dop", "mc"),
   #
   # Main Function --------------------------------------------------------------
 
+  dop.ci <- asymp.ci <- mc.ci <- c(NA, NA)
+
+  asymp.ab <- dop.ab <- mc.ab <- asmyp.se.ab <- dop.se.ab <- mc.se.ab <- NA
+
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Asymptotic Normal Confidence Interval ####
+  ## Asymptotic Normal and/or Distribution of Product Method ####
 
-  #...................
-  ### Point estimate ####
+  if (isTRUE("asymp" %in% print || "dop" %in% print)) {
 
-  asymp.ab <- a*b
+    #...................
+    ### Point estimate ####
 
-  #...................
-  ### Standard error ####
+    dop.ab <- asymp.ab <- a*b
 
-  switch(se, "sobel" = {
+    #...................
+    ### Standard error ####
 
-    asmyp.se.ab <- sqrt(a^2L*se.b^2L + b^2L*se.a^2L)
+    dop.se.ab <- asmyp.se.ab <- switch(se,
+                                       "sobel" = {
 
-  }, "aroian" = {
+                                          sqrt(a^2L*se.b^2L + b^2L*se.a^2L)
 
-    asmyp.se.ab <- sqrt(a^2L*se.b^2L + b^2L*se.a^2L + se.a^2L*se.b^2L)
+                                        }, "aroian" = {
 
-  }, "goodman" = {
+                                          sqrt(a^2L*se.b^2L + b^2L*se.a^2L + se.a^2L*se.b^2L)
 
-    asmyp.se.ab <- sqrt(a^2L*se.b^2L + b^2L*se.a^2L - se.a^2L*se.b^2L)
+                                        }, "goodman" = {
+
+                                          sqrt(a^2L*se.b^2L + b^2L*se.a^2L - se.a^2L*se.b^2L)
+
+                                        })
 
     # Negative standard error
     if (isTRUE(is.nan(asmyp.se.ab))) {
 
       if (isTRUE(all(print == "asymp"))) {
 
-        stop("Goodman standard error is undefined, please use a different method for standard error computation.",
-             call. = FALSE)
+        stop("Goodman standard error is undefined, please use a different method for standard error computation.", call. = FALSE)
 
-        asmyp.se.ab <- NA
+        dop.ab <- asmyp.se.ab <- NA
 
+      }
+
+    }
+
+    #...................
+    ### Asymptotic Normal Confidence Intervals ####
+
+    if (isTRUE("asymp" %in% print)) {
+
+      # Non-negative standard error
+      if (isTRUE(!is.na(asmyp.se.ab))) {
+
+        asymp.ci <- switch(alternative,
+                           two.sided = c(low = asymp.ab - qnorm((1L - conf.level) / 2L, lower.tail = FALSE) * asmyp.se.ab,
+                                         upp = asymp.ab + qnorm((1L - conf.level) / 2L, lower.tail = FALSE) * asmyp.se.ab),
+                                less = c(low = -Inf,
+                                         upp = asymp.ab + qnorm(1L - conf.level, lower.tail = FALSE) * asmyp.se.ab),
+                             greater = c(low = asymp.ab - qnorm(1L - conf.level, lower.tail = FALSE) * asmyp.se.ab,
+                                         upp = Inf))
+
+      # Negative standard error
       } else {
 
-        warning("Goodman standard error is undefined, please use a different method for standard error computation.",
-                call. = FALSE)
-
-        asmyp.se.ab <- NA
+        asymp.ci <- c(low = NA, upp = NA)
 
       }
 
     }
 
-  })
+    #...................
+    ### Distribution of Product Confidence Intervals ####
 
-  #...................
-  ### Confidence interval ####
+    if (isTRUE("dop" %in% print)) {
 
-  # Non-negative standard error
-  if (isTRUE(!is.na(asmyp.se.ab))) {
+      #...................
+      ### Confidence interval ####
 
-    asymp.ci <- switch(alternative,
-                       two.sided = c(low = asymp.ab - qnorm((1L - conf.level) / 2L, lower.tail = FALSE) * asmyp.se.ab,
-                                     upp = asymp.ab + qnorm((1L - conf.level) / 2L, lower.tail = FALSE) * asmyp.se.ab),
-                       less = c(low = -Inf,
-                                upp = asymp.ab + qnorm(1L - conf.level, lower.tail = FALSE) * asmyp.se.ab),
-                       greater = c(low = asymp.ab - qnorm(1L - conf.level, lower.tail = FALSE) * asmyp.se.ab,
-                                   upp = Inf))
+      dop.ci <- switch(alternative,
+                       two.sided = c(low = .qprodnormalMeeker((1L - conf.level) / 2L, a = a, b = b, se.a = se.a, se.b = se.b, lower.tail = TRUE) |> (\(p) if (isTRUE(is.list(p))) { NA } else { p })(),
+                                     upp = .qprodnormalMeeker((1L - conf.level) / 2L, a = a, b = b, se.a = se.a, se.b = se.b, lower.tail = FALSE) |> (\(p) if (isTRUE(is.list(p))) { NA } else { p })()),
+                            less = c(low = -Inf,
+                             upp = .qprodnormalMeeker((1L - conf.level), a = a, b = b, se.a = se.a, se.b = se.b, lower.tail = FALSE) |> (\(p) if (isTRUE(is.list(p))) { NA } else { p })()),
+                         greater = c(low = .qprodnormalMeeker((1L - conf.level), a = a, b = b, se.a = se.a, se.b = se.b, lower.tail = TRUE) |> (\(p) if (isTRUE(is.list(p))) { NA } else { p })(),
+                                     upp = Inf))
 
-  # Negative standard error
-  } else {
+      if (isTRUE(all(is.na(dop.ci)))) {
 
-    asymp.ci <- c(low = NA, upp = NA)
+        if (isTRUE(all(print == "dop"))) {
 
-  }
+          stop("Confidence intervals based on the distribution of the product method could not be computed.", call. = FALSE)
 
-  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## Distribution of Product Method ####
+        }  else {
 
-  qprodnormalMeeker <- function(p, a, b, se.a, se.b, lower.tail = TRUE) {
+          warning("Confidence intervals based on the distribution of the product method could not be computed.", call. = FALSE)
 
-    max.iter <- 1000
+        }
 
-    mu.a <- a / se.a
-    mu.b <- b / se.b
-
-    se.ab <- sqrt(1L + mu.a^2L + mu.b^2L)
-
-    if (lower.tail == FALSE) {
-
-      u0 <- mu.a*mu.b + 6L*se.ab
-      l0 <- mu.a*mu.b - 6L*se.ab
-      alpha <- 1L - p
-
-    } else {
-
-      l0 <- mu.a*mu.b - 6L*se.ab
-      u0 <- mu.a*mu.b + 6L*se.ab
-      alpha <- p
-
-    }
-
-    gx <- function(x, z) {
-
-      mu.a.on.b <- mu.a
-      integ <- pnorm(sign(x)*(z / x - mu.a.on.b))*dnorm(x - mu.b)
-
-      return(integ)
-
-    }
-
-    fx <- function(z) {
-
-      return(integrate(gx, lower = -Inf, upper = Inf, z = z)$value - alpha)
-
-    }
-
-    p.l <- fx(l0)
-    p.u <- fx(u0)
-    iter <- 0L
-
-    while (p.l > 0L) {
-
-      iter <- iter + 1
-      l0 <- l0 - 0.5*se.ab
-      p.l <- fx(l0)
-
-      if (iter > max.iter) {
-
-        cat(" No initial valid lower bound interval!\n")
-        return(list(q = NA, error = NA))
+        print <- misty::chr.omit(print, omit = "dop")
 
       }
 
     }
 
-    iter <- 0 #Reset iteration counter
-    while (p.u < 0L) {
-
-      iter <- iter + 1L
-      u0 <- u0 + 0.5*se.ab
-      p.u <- fx(u0)
-
-      if (iter > max.iter) {
-
-        cat(" No initial valid upper bound interval!\n")
-        return(list(q = NA,error = NA))
-
-      }
-
-    }
-
-    res <- uniroot(fx, c(l0, u0))
-    new <- res$root
-    new <- new*se.a*se.b
-
-    return(new)
-
   }
 
-  #...................
-  ### Point estimate ####
-
-  dop.ab <- asymp.ab
-
-  #...................
-  ### Standard error ####
-
-  dop.se.ab <- asmyp.se.ab
-
-  # Negative standard error
-  if (isTRUE(is.na(dop.se.ab) & !"asymp" %in% print)) {
-
-    warning("Goodman standard error is undefined.", call. = FALSE)
-
-    dop.se.ab <- NA
-
-  }
-
-  #...................
-  ### Confidence interval ####
-
-  dop.ci <- switch(alternative,
-                   two.sided = c(low = qprodnormalMeeker((1L - conf.level) / 2L, a = a, b = b, se.a = se.a, se.b = se.b, lower.tail = TRUE),
-                                 upp = qprodnormalMeeker((1L - conf.level) / 2L, a = a, b = b, se.a = se.a, se.b = se.b, lower.tail = FALSE)),
-                   less = c(low = -Inf,
-                            upp = qprodnormalMeeker((1L - conf.level), a = a, b = b, se.a = se.a, se.b = se.b, lower.tail = FALSE)),
-                   greater = c(low = qprodnormalMeeker((1L - conf.level), a = a, b = b, se.a = se.a, se.b = se.b, lower.tail = TRUE),
-                               upp = Inf))
-
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Monte Carlo Method ####
 
-  #...................
-  ### Random Number Generation ####
+  if (isTRUE("mc" %in% print)) {
 
-  if (isTRUE(!is.null(seed))) {
+    #...................
+    ### Random Number Generation ####
 
-    set.seed(seed)
+    if (isTRUE(!is.null(seed))) { set.seed(seed) }
+
+    #...................
+    ### Monte Carlo ####
+
+    ab <- t(crossprod(chol(matrix(c(se.a^2L, se.a*se.b*0L, se.a*se.b*0L, se.b^2L), nrow = 2L)), (matrix(rnorm(2L*nrep), ncol = nrep))) + c(a, b)) |> (\(p) p[, 1L]*p[, 2L])()
+
+    #...................
+    ### Point estimate ####
+
+    mc.ab <- mean(ab)
+
+    #...................
+    ### Standard error ####
+
+    mc.se.ab <- sd(ab)
+
+    #...................
+    ### Confidence interval ####
+
+    mc.ci <- switch(alternative,
+                    two.sided = c(low = quantile(ab, (1L - conf.level) / 2L), upp = quantile(ab, 1L - (1L - conf.level) / 2L)),
+                    less = c(low = -Inf, upp = quantile(ab, conf.level)),
+                    greater = c(low = quantile(ab, 1L - conf.level), upp = Inf))
 
   }
 
-  #...................
-  ### Monte Carlo ####
-
-  a_b <- matrix(rnorm(2L*nrep), ncol = nrep)
-
-  a_b <- t(crossprod(chol(matrix(c(se.a^2L, se.a*se.b*0L, se.a*se.b*0L, se.b^2L), nrow = 2L)), a_b) + c(a, b))
-
-  ab <- a_b[, 1L]*a_b[, 2L]
-
-  #...................
-  ### Point estimate ####
-
-  mc.ab <- mean(ab)
-
-  #...................
-  ### Standard error ####
-
-  mc.se.ab <- sd(ab)
-
-  #...................
-  ### Confidence interval ####
-
-  mc.ci <- switch(alternative,
-                  two.sided = c(low = quantile(ab, (1L - conf.level) / 2L),
-                                upp = quantile(ab, 1L - (1L - conf.level) / 2L)),
-                  less = c(low = -Inf,
-                           upp = quantile(ab, conf.level)),
-                  greater = c(low = quantile(ab, 1L - conf.level),
-                              upp = Inf))
-
   #_____________________________________________________________________________
   #
   # Return object --------------------------------------------------------------
@@ -484,15 +394,10 @@ indirect <- function(a, b, se.a, se.b, print = c("all", "asymp", "dop", "mc"),
   object <- list(call = match.call(),
                  type = "indirect",
                  data = list(a = a, b = b, se.a = se.b, se.b = se.b),
-                 args = list(print = print, se = se, nrep = nrep, alternative = alternative,
-                             seed = seed, conf.level = conf.level, digits = digits,
-                             write = write, append = append, check = check, output = output),
-                 result = list(asymp = data.frame(est = asymp.ab, se = asmyp.se.ab,
-                                                  low = asymp.ci[1L], upp = asymp.ci[2L], row.names = NULL),
-                               dop = data.frame(est = dop.ab, se = dop.se.ab,
-                                                low = dop.ci[1L], upp = dop.ci[2L], row.names = NULL),
-                               mc = data.frame(est = mc.ab, se = mc.se.ab,
-                                               low = mc.ci[1L], upp = mc.ci[2L], row.names = NULL)))
+                 args = list(print = print, se = se, nrep = nrep, alternative = alternative, seed = seed, conf.level = conf.level, digits = digits, write = write, append = append, check = check, output = output),
+                 result = list(asymp = data.frame(est = asymp.ab, se = asmyp.se.ab, low = asymp.ci[1L], upp = asymp.ci[2L], row.names = NULL),
+                               dop = data.frame(est = dop.ab, se = dop.se.ab, low = dop.ci[1L], upp = dop.ci[2L], row.names = NULL),
+                               mc = data.frame(est = mc.ab, se = mc.se.ab, low = mc.ci[1L], upp = mc.ci[2L], row.names = NULL)))
 
   class(object) <- "misty.object"
 
