@@ -1481,19 +1481,23 @@ multilevel.cfa <- function(data, ..., cluster, model = NULL, rescov = NULL,
                                # Second column
                                unlist(c("", "",
                                         # Estimator
-                                        ifelse(lavaan::lavInspect(model.fit, what = "options")$test == "standard", "ML", "MLR"),
+                                        lavaan::lavTech(model.fit, what = "options")$test |> (\(p) if (isTRUE(length(p) != 1L)) { "standard" } else { "MLR" })(),
                                         # Optimization method
                                         toupper(lavaan::lavTech(model.fit, what = "options")$optim.method), "",
                                         # Test statistic
-                                        switch(lavaan::lavTech(model.fit, what = "options")$test,
+                                        switch(lavaan::lavTech(model.fit, what = "options")$test |> (\(p) if (isTRUE(length(p) != 1L)) { misty::chr.omit(p, omit = "standard") } else { p })(),
                                                "standard" = "Conventional",
                                                "satorra.bentler" = "Satorra-Bentler",
                                                "scaled.shifted" = "Scale-Shifted",
                                                "mean.var.adjusted" = "Satterthwaite",
-                                               "yuan.bentler.mplus" = "Yuan-Bentler"),
+                                               "yuan.bentler.mplus" = "Yuan-Bentler",
+                                               "browne.residual.adf" = "Browne's Residual-Based ADF Theory",
+                                               "browne.residual.nt" = "Browne's Residual-Based Normal Theory"),
+                                        # Standard errors
                                         switch(lavaan::lavTech(model.fit, what = "options")$se,
                                                "standard" = "Conventional",
                                                "robust.sem" = "Conventional Robust",
+                                               "robust.sem.nt" = "Conventional Robust",
                                                "robust.huber.white" = "Huber-White",
                                                "robust.cluster" = "Cluster-Robust H-W",
                                                "robust.cluster.sem" = "Cluster-Robust Conven",
